@@ -103,10 +103,7 @@ static struct {
  * Free row. This closes and frees row's list, then
  * the pitem itself is freed.
  */
-static void
-free_ritem(Dt_t* d, pitem* p,Dtdisc_t* ds)
-{
-  (void)d;
+static void free_ritem(pitem *p, Dtdisc_t *ds) {
   (void)ds;
 
   dtclose (p->u.rp);
@@ -117,10 +114,7 @@ free_ritem(Dt_t* d, pitem* p,Dtdisc_t* ds)
  * Generic Dt free. Only frees container, assuming contents
  * have been copied elsewhere.
  */
-static void
-free_item(Dt_t* d, void* p,Dtdisc_t* ds)
-{
-  (void)d;
+static void free_item(void *p, Dtdisc_t *ds) {
   (void)ds;
 
   free (p);
@@ -152,10 +146,7 @@ cleanCell (htmlcell_t* cp)
 /* free_citem:
  * Free cell item during parsing. This frees cell and pitem.
  */
-static void
-free_citem(Dt_t* d, pitem* p,Dtdisc_t* ds)
-{
-  (void)d;
+static void free_citem(pitem *p, Dtdisc_t *ds) {
   (void)ds;
 
   cleanCell (p->u.cp);
@@ -185,20 +176,14 @@ typedef struct {
     htextspan_t  lp;
 } fspan;
 
-static void 
-free_fitem(Dt_t* d, fitem* p, Dtdisc_t* ds)
-{
-    (void)d;
+static void free_fitem(fitem *p, Dtdisc_t *ds) {
     (void)ds;
 
     free (p->ti.str);
     free (p);
 }
 
-static void 
-free_fspan(Dt_t* d, fspan* p, Dtdisc_t* ds)
-{
-    (void)d;
+static void free_fspan(fspan *p, Dtdisc_t *ds) {
     (void)ds;
 
     textspan_t* ti;
@@ -460,7 +445,7 @@ popFont (void)
 }
 
 
-#line 464 "htmlparse.c"
+#line 449 "htmlparse.c"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -600,7 +585,7 @@ extern int htmldebug;
 #if ! defined HTMLSTYPE && ! defined HTMLSTYPE_IS_DECLARED
 union HTMLSTYPE
 {
-#line 405 "../../lib/common/htmlparse.y"
+#line 390 "../../lib/common/htmlparse.y"
 
   int    i;
   htmltxt_t*  txt;
@@ -610,7 +595,7 @@ union HTMLSTYPE
   htmlimg_t*   img;
   pitem*       p;
 
-#line 614 "htmlparse.c"
+#line 599 "htmlparse.c"
 
 };
 typedef union HTMLSTYPE HTMLSTYPE;
@@ -989,13 +974,13 @@ static const yytype_int8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
-       0,   437,   437,   438,   439,   442,   445,   446,   449,   450,
-     451,   452,   453,   454,   455,   456,   457,   458,   461,   464,
-     467,   470,   473,   476,   479,   482,   485,   488,   491,   494,
-     497,   500,   503,   506,   509,   510,   513,   514,   517,   517,
-     538,   539,   540,   541,   542,   543,   546,   547,   550,   551,
-     552,   555,   555,   558,   559,   560,   563,   563,   564,   564,
-     565,   565,   566,   566,   569,   570,   573,   574,   577,   578
+       0,   422,   422,   423,   424,   427,   430,   431,   434,   435,
+     436,   437,   438,   439,   440,   441,   442,   443,   446,   449,
+     452,   455,   458,   461,   464,   467,   470,   473,   476,   479,
+     482,   485,   488,   491,   494,   495,   498,   499,   502,   502,
+     523,   524,   525,   526,   527,   528,   531,   532,   535,   536,
+     537,   540,   540,   543,   544,   545,   548,   548,   549,   549,
+     550,   550,   551,   551,   554,   555,   558,   559,   562,   563
 };
 #endif
 
@@ -1899,151 +1884,151 @@ yyreduce:
   switch (yyn)
     {
   case 2:
-#line 437 "../../lib/common/htmlparse.y"
+#line 422 "../../lib/common/htmlparse.y"
                                    { HTMLstate.lbl = mkLabel((yyvsp[-1].txt),HTML_TEXT); }
-#line 1905 "htmlparse.c"
+#line 1890 "htmlparse.c"
     break;
 
   case 3:
-#line 438 "../../lib/common/htmlparse.y"
+#line 423 "../../lib/common/htmlparse.y"
                                     { HTMLstate.lbl = mkLabel((yyvsp[-1].tbl),HTML_TBL); }
-#line 1911 "htmlparse.c"
+#line 1896 "htmlparse.c"
     break;
 
   case 4:
-#line 439 "../../lib/common/htmlparse.y"
+#line 424 "../../lib/common/htmlparse.y"
               { cleanup(); YYABORT; }
-#line 1917 "htmlparse.c"
+#line 1902 "htmlparse.c"
     break;
 
   case 5:
-#line 442 "../../lib/common/htmlparse.y"
+#line 427 "../../lib/common/htmlparse.y"
                 { (yyval.txt) = mkText(); }
-#line 1923 "htmlparse.c"
+#line 1908 "htmlparse.c"
     break;
 
   case 8:
-#line 449 "../../lib/common/htmlparse.y"
+#line 434 "../../lib/common/htmlparse.y"
                   { appendFItemList(HTMLstate.str);}
-#line 1929 "htmlparse.c"
+#line 1914 "htmlparse.c"
     break;
 
   case 9:
-#line 450 "../../lib/common/htmlparse.y"
+#line 435 "../../lib/common/htmlparse.y"
               {appendFLineList((yyvsp[0].i));}
-#line 1935 "htmlparse.c"
+#line 1920 "htmlparse.c"
     break;
 
   case 18:
-#line 461 "../../lib/common/htmlparse.y"
+#line 446 "../../lib/common/htmlparse.y"
               { pushFont ((yyvsp[0].font)); }
-#line 1941 "htmlparse.c"
+#line 1926 "htmlparse.c"
     break;
 
   case 19:
-#line 464 "../../lib/common/htmlparse.y"
+#line 449 "../../lib/common/htmlparse.y"
                     { popFont (); }
-#line 1947 "htmlparse.c"
+#line 1932 "htmlparse.c"
     break;
 
   case 20:
-#line 467 "../../lib/common/htmlparse.y"
+#line 452 "../../lib/common/htmlparse.y"
                   {pushFont((yyvsp[0].font));}
-#line 1953 "htmlparse.c"
+#line 1938 "htmlparse.c"
     break;
 
   case 21:
-#line 470 "../../lib/common/htmlparse.y"
+#line 455 "../../lib/common/htmlparse.y"
                       {popFont();}
-#line 1959 "htmlparse.c"
+#line 1944 "htmlparse.c"
     break;
 
   case 22:
-#line 473 "../../lib/common/htmlparse.y"
+#line 458 "../../lib/common/htmlparse.y"
               {pushFont((yyvsp[0].font));}
-#line 1965 "htmlparse.c"
+#line 1950 "htmlparse.c"
     break;
 
   case 23:
-#line 476 "../../lib/common/htmlparse.y"
+#line 461 "../../lib/common/htmlparse.y"
                   {popFont();}
-#line 1971 "htmlparse.c"
+#line 1956 "htmlparse.c"
     break;
 
   case 24:
-#line 479 "../../lib/common/htmlparse.y"
+#line 464 "../../lib/common/htmlparse.y"
              {pushFont((yyvsp[0].font));}
-#line 1977 "htmlparse.c"
+#line 1962 "htmlparse.c"
     break;
 
   case 25:
-#line 482 "../../lib/common/htmlparse.y"
+#line 467 "../../lib/common/htmlparse.y"
                  {popFont();}
-#line 1983 "htmlparse.c"
+#line 1968 "htmlparse.c"
     break;
 
   case 26:
-#line 485 "../../lib/common/htmlparse.y"
+#line 470 "../../lib/common/htmlparse.y"
                         {pushFont((yyvsp[0].font));}
-#line 1989 "htmlparse.c"
+#line 1974 "htmlparse.c"
     break;
 
   case 27:
-#line 488 "../../lib/common/htmlparse.y"
+#line 473 "../../lib/common/htmlparse.y"
                             {popFont();}
-#line 1995 "htmlparse.c"
+#line 1980 "htmlparse.c"
     break;
 
   case 28:
-#line 491 "../../lib/common/htmlparse.y"
+#line 476 "../../lib/common/htmlparse.y"
                       {pushFont((yyvsp[0].font));}
-#line 2001 "htmlparse.c"
+#line 1986 "htmlparse.c"
     break;
 
   case 29:
-#line 494 "../../lib/common/htmlparse.y"
+#line 479 "../../lib/common/htmlparse.y"
                           {popFont();}
-#line 2007 "htmlparse.c"
+#line 1992 "htmlparse.c"
     break;
 
   case 30:
-#line 497 "../../lib/common/htmlparse.y"
+#line 482 "../../lib/common/htmlparse.y"
             {pushFont((yyvsp[0].font));}
-#line 2013 "htmlparse.c"
+#line 1998 "htmlparse.c"
     break;
 
   case 31:
-#line 500 "../../lib/common/htmlparse.y"
+#line 485 "../../lib/common/htmlparse.y"
                 {popFont();}
-#line 2019 "htmlparse.c"
+#line 2004 "htmlparse.c"
     break;
 
   case 32:
-#line 503 "../../lib/common/htmlparse.y"
+#line 488 "../../lib/common/htmlparse.y"
             {pushFont((yyvsp[0].font));}
-#line 2025 "htmlparse.c"
+#line 2010 "htmlparse.c"
     break;
 
   case 33:
-#line 506 "../../lib/common/htmlparse.y"
+#line 491 "../../lib/common/htmlparse.y"
                 {popFont();}
-#line 2031 "htmlparse.c"
+#line 2016 "htmlparse.c"
     break;
 
   case 34:
-#line 509 "../../lib/common/htmlparse.y"
+#line 494 "../../lib/common/htmlparse.y"
                        { (yyval.i) = (yyvsp[-1].i); }
-#line 2037 "htmlparse.c"
+#line 2022 "htmlparse.c"
     break;
 
   case 35:
-#line 510 "../../lib/common/htmlparse.y"
+#line 495 "../../lib/common/htmlparse.y"
               { (yyval.i) = (yyvsp[0].i); }
-#line 2043 "htmlparse.c"
+#line 2028 "htmlparse.c"
     break;
 
   case 38:
-#line 517 "../../lib/common/htmlparse.y"
+#line 502 "../../lib/common/htmlparse.y"
                           { 
           if (nonSpace(agxbuse(HTMLstate.str))) {
             htmlerror ("Syntax error: non-space string used before <TABLE>");
@@ -2055,11 +2040,11 @@ yyreduce:
           (yyvsp[0].tbl)->font = HTMLstate.fontstack->cfont;
           (yyval.tbl) = (yyvsp[0].tbl);
         }
-#line 2059 "htmlparse.c"
+#line 2044 "htmlparse.c"
     break;
 
   case 39:
-#line 528 "../../lib/common/htmlparse.y"
+#line 513 "../../lib/common/htmlparse.y"
                                    {
           if (nonSpace(agxbuse(HTMLstate.str))) {
             htmlerror ("Syntax error: non-space string used after </TABLE>");
@@ -2068,155 +2053,155 @@ yyreduce:
           (yyval.tbl) = HTMLstate.tblstack;
           HTMLstate.tblstack = HTMLstate.tblstack->u.p.prev;
         }
-#line 2072 "htmlparse.c"
+#line 2057 "htmlparse.c"
     break;
 
   case 40:
-#line 538 "../../lib/common/htmlparse.y"
+#line 523 "../../lib/common/htmlparse.y"
                   { (yyval.tbl) = (yyvsp[0].tbl); }
-#line 2078 "htmlparse.c"
+#line 2063 "htmlparse.c"
     break;
 
   case 41:
-#line 539 "../../lib/common/htmlparse.y"
+#line 524 "../../lib/common/htmlparse.y"
                               { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 2084 "htmlparse.c"
+#line 2069 "htmlparse.c"
     break;
 
   case 42:
-#line 540 "../../lib/common/htmlparse.y"
+#line 525 "../../lib/common/htmlparse.y"
                                   { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 2090 "htmlparse.c"
+#line 2075 "htmlparse.c"
     break;
 
   case 43:
-#line 541 "../../lib/common/htmlparse.y"
+#line 526 "../../lib/common/htmlparse.y"
                                         { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 2096 "htmlparse.c"
+#line 2081 "htmlparse.c"
     break;
 
   case 44:
-#line 542 "../../lib/common/htmlparse.y"
+#line 527 "../../lib/common/htmlparse.y"
                                       { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 2102 "htmlparse.c"
+#line 2087 "htmlparse.c"
     break;
 
   case 45:
-#line 543 "../../lib/common/htmlparse.y"
+#line 528 "../../lib/common/htmlparse.y"
                               { (yyval.tbl)=(yyvsp[-1].tbl); }
-#line 2108 "htmlparse.c"
+#line 2093 "htmlparse.c"
     break;
 
   case 48:
-#line 550 "../../lib/common/htmlparse.y"
+#line 535 "../../lib/common/htmlparse.y"
            { (yyval.p) = (yyvsp[0].p); }
-#line 2114 "htmlparse.c"
+#line 2099 "htmlparse.c"
     break;
 
   case 49:
-#line 551 "../../lib/common/htmlparse.y"
+#line 536 "../../lib/common/htmlparse.y"
                 { (yyval.p) = (yyvsp[0].p); }
-#line 2120 "htmlparse.c"
+#line 2105 "htmlparse.c"
     break;
 
   case 50:
-#line 552 "../../lib/common/htmlparse.y"
+#line 537 "../../lib/common/htmlparse.y"
                    { (yyvsp[-2].p)->ruled = 1; (yyval.p) = (yyvsp[0].p); }
-#line 2126 "htmlparse.c"
+#line 2111 "htmlparse.c"
     break;
 
   case 51:
-#line 555 "../../lib/common/htmlparse.y"
+#line 540 "../../lib/common/htmlparse.y"
             { addRow (); }
-#line 2132 "htmlparse.c"
+#line 2117 "htmlparse.c"
     break;
 
   case 52:
-#line 555 "../../lib/common/htmlparse.y"
+#line 540 "../../lib/common/htmlparse.y"
                                            { (yyval.p) = lastRow(); }
-#line 2138 "htmlparse.c"
+#line 2123 "htmlparse.c"
     break;
 
   case 53:
-#line 558 "../../lib/common/htmlparse.y"
+#line 543 "../../lib/common/htmlparse.y"
              { (yyval.cell) = (yyvsp[0].cell); }
-#line 2144 "htmlparse.c"
+#line 2129 "htmlparse.c"
     break;
 
   case 54:
-#line 559 "../../lib/common/htmlparse.y"
+#line 544 "../../lib/common/htmlparse.y"
                    { (yyval.cell) = (yyvsp[0].cell); }
-#line 2150 "htmlparse.c"
+#line 2135 "htmlparse.c"
     break;
 
   case 55:
-#line 560 "../../lib/common/htmlparse.y"
+#line 545 "../../lib/common/htmlparse.y"
                       { (yyvsp[-2].cell)->ruled |= HTML_VRULE; (yyval.cell) = (yyvsp[0].cell); }
-#line 2156 "htmlparse.c"
+#line 2141 "htmlparse.c"
     break;
 
   case 56:
-#line 563 "../../lib/common/htmlparse.y"
+#line 548 "../../lib/common/htmlparse.y"
                         { setCell((yyvsp[-1].cell),(yyvsp[0].tbl),HTML_TBL); }
-#line 2162 "htmlparse.c"
+#line 2147 "htmlparse.c"
     break;
 
   case 57:
-#line 563 "../../lib/common/htmlparse.y"
+#line 548 "../../lib/common/htmlparse.y"
                                                                 { (yyval.cell) = (yyvsp[-3].cell); }
-#line 2168 "htmlparse.c"
+#line 2153 "htmlparse.c"
     break;
 
   case 58:
-#line 564 "../../lib/common/htmlparse.y"
+#line 549 "../../lib/common/htmlparse.y"
                        { setCell((yyvsp[-1].cell),(yyvsp[0].txt),HTML_TEXT); }
-#line 2174 "htmlparse.c"
+#line 2159 "htmlparse.c"
     break;
 
   case 59:
-#line 564 "../../lib/common/htmlparse.y"
+#line 549 "../../lib/common/htmlparse.y"
                                                                 { (yyval.cell) = (yyvsp[-3].cell); }
-#line 2180 "htmlparse.c"
+#line 2165 "htmlparse.c"
     break;
 
   case 60:
-#line 565 "../../lib/common/htmlparse.y"
+#line 550 "../../lib/common/htmlparse.y"
                     { setCell((yyvsp[-1].cell),(yyvsp[0].img),HTML_IMAGE); }
-#line 2186 "htmlparse.c"
+#line 2171 "htmlparse.c"
     break;
 
   case 61:
-#line 565 "../../lib/common/htmlparse.y"
+#line 550 "../../lib/common/htmlparse.y"
                                                               { (yyval.cell) = (yyvsp[-3].cell); }
-#line 2192 "htmlparse.c"
+#line 2177 "htmlparse.c"
     break;
 
   case 62:
-#line 566 "../../lib/common/htmlparse.y"
+#line 551 "../../lib/common/htmlparse.y"
               { setCell((yyvsp[0].cell),mkText(),HTML_TEXT); }
-#line 2198 "htmlparse.c"
+#line 2183 "htmlparse.c"
     break;
 
   case 63:
-#line 566 "../../lib/common/htmlparse.y"
+#line 551 "../../lib/common/htmlparse.y"
                                                              { (yyval.cell) = (yyvsp[-2].cell); }
-#line 2204 "htmlparse.c"
+#line 2189 "htmlparse.c"
     break;
 
   case 64:
-#line 569 "../../lib/common/htmlparse.y"
+#line 554 "../../lib/common/htmlparse.y"
                          { (yyval.img) = (yyvsp[-1].img); }
-#line 2210 "htmlparse.c"
+#line 2195 "htmlparse.c"
     break;
 
   case 65:
-#line 570 "../../lib/common/htmlparse.y"
+#line 555 "../../lib/common/htmlparse.y"
                { (yyval.img) = (yyvsp[0].img); }
-#line 2216 "htmlparse.c"
+#line 2201 "htmlparse.c"
     break;
 
 
-#line 2220 "htmlparse.c"
+#line 2205 "htmlparse.c"
 
       default: break;
     }
@@ -2448,7 +2433,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 582 "../../lib/common/htmlparse.y"
+#line 567 "../../lib/common/htmlparse.y"
 
 
 /* parseHTML:
